@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-aws-iam-role" "1.6.5"
+(define-package "org-aws-iam-role" "20251026.2308"
   "Browse, modify, and simulate AWS IAM Roles in Org Babel."
   '((emacs   "29.1")
     (async   "1.9")
     (promise "1.1"))
   :url "https://github.com/will-abb/org-aws-iam-role"
-  :commit "4c6cdde1efd1f33a4e2434db7af7617ce590e90c"
-  :revdesc "v1.6.5-0-g4c6cdde1efd1"
+  :commit "9c246fe5c716e8515524bd7c1dfd6dcd64114375"
+  :revdesc "9c246fe5c716"
   :keywords '("aws" "iam" "org" "babel" "tools")
   :authors '(("William Bosch-Bello" . "williamsbosch@gmail.com"))
   :maintainers '(("William Bosch-Bello" . "williamsbosch@gmail.com")))
